@@ -22,11 +22,35 @@ const string CDasherInterface::EmptyString = "";
 
 
 CDasherInterface::CDasherInterface()
-	: m_DashEditbox(0), m_DasherScreen(0), m_LanguageModel(0), TrainContext(0), m_Alphabet(0),
-	  m_DasherModel(0), m_DasherView(0), AlphabetID(""), LanguageModelID(-1), ViewID(-1),
-	  m_MaxBitRate(-1), m_Orientation(Opts::LeftToRight), m_SettingsStore(0), m_SettingsUI(0),
-	  m_UserLocation("usr_"), m_SystemLocation("sys_"), m_AlphIO(0), m_TrainFile(""),
-	  m_DasherFont(""), m_EditFont(""), m_EditFontSize(0), m_DasherFontSize(Opts::Normal), m_DrawKeyboard(false), m_Colours(0), m_ColourIO(0), m_ColourMode(0), m_Paused(0), m_PaletteChange(0)
+	: 
+m_Alphabet(0), 
+m_Colours(0), 
+m_LanguageModel(0), 
+m_DasherModel(0), 
+m_DashEditbox(0), 
+m_DasherScreen(0), 
+m_DasherView(0), 
+m_SettingsStore(0), 
+m_SettingsUI(0),
+m_AlphIO(0), 
+m_ColourIO(0), 
+TrainContext(0), 
+AlphabetID(""), 
+LanguageModelID(-1), 
+ViewID(-1),
+m_MaxBitRate(-1), 
+m_DrawKeyboard(false), 
+m_ColourMode(0), 
+m_Paused(0), 
+m_PaletteChange(0),
+m_Orientation(Opts::LeftToRight), 
+m_UserLocation("usr_"), 
+m_SystemLocation("sys_"), 
+m_TrainFile(""),
+m_DasherFont(""), 
+m_DasherFontSize(Opts::Normal), 
+m_EditFont(""), 
+m_EditFontSize(0)
 {
 }
 
@@ -98,7 +122,7 @@ void CDasherInterface::CreateDasherModel()
 
   if (m_DashEditbox!=0 && m_LanguageModel!=0) {
     delete m_DasherModel;
-    m_DasherModel = new CDasherModel(m_DashEditbox, m_LanguageModel, m_Dimensions, m_Eyetracker);
+    m_DasherModel = new CDasherModel(m_DashEditbox, m_LanguageModel, m_Dimensions, m_Eyetracker, m_Paused);
     if (m_MaxBitRate>=0)
       m_DasherModel->SetMaxBitrate(m_MaxBitRate);
     if (ViewID!=-1)
@@ -111,9 +135,16 @@ void CDasherInterface::CreateDasherModel()
 
 void CDasherInterface::Start()
 {
-	if (m_DasherModel!=0)
+    m_Paused=false;
+	if (m_DasherModel!=0) {
 		m_DasherModel->Start();
-	m_Paused=false;
+        m_DasherModel->Set_paused(m_Paused);
+	}
+    if (m_DasherView!=0) {
+        m_DasherView->ResetSum();
+        m_DasherView->ResetSumCounter();
+        m_DasherView->ResetYAutoOffset();
+    }
 }
 
 
@@ -125,6 +156,9 @@ void CDasherInterface::PauseAt(int MouseX, int MouseY)
 			m_DashEditbox->CopyAll();
 	}	
 	m_Paused=true;
+    if (m_DasherModel!=0) {
+        m_DasherModel->Set_paused(m_Paused);
+    }
 }
 
 void CDasherInterface::Halt()
@@ -135,8 +169,15 @@ void CDasherInterface::Halt()
 
 void CDasherInterface::Unpause(unsigned long Time)
 {
-	if (m_DasherModel!=0)
+	m_Paused=false;
+    if (m_DasherModel!=0) {
 		m_DasherModel->Reset_framerate(Time);
+        m_DasherModel->Set_paused(m_Paused);
+    }
+    if (m_DasherView!=0) {
+        m_DasherView->ResetSum();
+        m_DasherView->ResetSumCounter();
+    }
 }
 
 
@@ -313,7 +354,6 @@ void CDasherInterface::ChangeMaxBitRate(double NewMaxBitRate)
 	}
 }
 
-
 void CDasherInterface::ChangeLanguageModel(unsigned int NewLanguageModelID)
 {
 	LanguageModelID = NewLanguageModelID;
@@ -892,3 +932,25 @@ void CDasherInterface::Render()
   if (m_DasherView!=0)
     m_DasherView->Render();
 }
+
+int CDasherInterface::GetOneButton() {
+  if (m_DasherView!=0) {
+    return m_DasherView->GetOneButton();
+  }
+  return -1;
+}
+
+int CDasherInterface::GetAutoOffset() {
+  if (m_DasherView!=0) {
+    return m_DasherView->GetAutoOffset();
+  }
+  return -1;
+}
+
+
+void CDasherInterface::SetOneButton(int Value) {
+  if (m_DasherView!=0) {
+    m_DasherView->SetOneButton(Value);
+  }
+}
+
