@@ -11,13 +11,12 @@
 #include <cspi/spi.h>
 #include <libgnomeui/gnome-ui-init.h>
 #endif
-#include <popt.h>
 #include <vector>
 #include "DasherTypes.h"
 
 using namespace Dasher;
 
-enum accessibletype { menus=1, toolbars=2, pushbuttons=3, focusables=4 };
+enum accessibletype { menus=1, toolbars=2, pushbuttons=3, focusables=4, textenter=5 };
 
 void setupa11y();
 void cleanupa11y();
@@ -27,6 +26,7 @@ ControlTree* buildcontroltree();
 ControlTree* buildmovetree(ControlTree* movetree);
 ControlTree* builddeletetree(ControlTree* movetree);
 ControlTree* buildspeaktree(ControlTree* speaktree);
+ControlTree* buildspeedtree(ControlTree* speedtree);
 void deletemenutree();
 #ifdef GNOME_A11Y
 bool buildmenutree(Accessible *parent, ControlTree *ctree, accessibletype Type);
